==> php55-owncloud-8.2.0.tgz: share/owncloud/apps/files/l10n/ta_LK.js <==
OC.L10N.register(
    "files",
    {
    "No file was uploaded. Unknown error" : "ஒரு கோப்பும் பதிவேற்றப்படவில்லை. அறியப்படாத வழு",
    "There is no error, the file uploaded with success" : "இங்கு வழு இல்லை, கோப்பு வெற்றிகரமாக பதிவேற்றப்பட்டது",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "பதிவேற்றப்பட்ட கோப்பானது HTML  படிவத்தில் குறிப்பிடப்பட்டுள்ள MAX_FILE_SIZE  directive ஐ விட கூடியது",
    "The uploaded file was only partially uploaded" : "பதிவேற்றப்பட்ட கோப்பானது பகுதியாக மட்டுமே பதிவேற்றப்பட்டுள்ளது",
    "No file was uploaded" : "எந்த கோப்பும் பதிவேற்றப்படவில்லை",
    "Missing a temporary folder" : "ஒரு தற்காலிகமான கோப்புறையை காணவில்லை",
    "Failed to write to disk" : "வட்டில் எழுத முடியவில்லை",
    "Files" : "கோப்புகள்",
    "Favorites" : "விருப்பங்கள்",
    "Home" : "அகம்",
    "Close" : "மூடுக",
    "Upload cancelled." : "பதிவேற்றல் இரத்து செய்யப்பட்டுள்ளது",
    "File upload is in progress. Leaving the page now will cancel the upload." : "கோப்பு பதிவேற்றம் செயல்பாட்டில் உள்ளது. இந்தப் பக்கத்திலிருந்து வெறியேறுவதானது பதிவேற்றலை இரத்து செய்யும்.",
    "Actions" : "செயல்கள்",
    "Download" : "பதிவிறக்குக",
    "Rename" : "பெயர்மாற்றம்",
    "Delete" : "நீக்குக",
    "Details" : "விவரங்கள்",
    "Select" : "தெரிக",
    "Pending" : "நிலுவையிலுள்ள",
    "Error" : "வழு",
    "{new_name} already exists" : "{new_name} ஏற்கனவே உள்ளது",
    "Name" : "பெயர்",
    "Size" : "அளவு",
    "Modified" : "மாற்றப்பட்டது",
    "New" : "புதிய",
    "Favorite" : "விருப்பமான",
    "Upload" : "பதிவேற்றுக",
    "Text file" : "கோப்பு உரை",
    "Folder" : "கோப்புறை",
    "File handling" : "கோப்பு கையாளுதல்",
    "Maximum upload size" : "பதிவேற்றக்கூடிய ஆகக்கூடிய அளவு ",
    "max. possible: " : "ஆகக் கூடியது:",
    "Save" : "சேமிக்க ",
    "Settings" : "அமைப்புகள்",
    "Cancel upload" : "பதிவேற்றலை இரத்து செய்க",
    "Upload too large" : "பதிவேற்றல் மிகப்பெரியது",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "நீங்கள் பதிவேற்ற முயற்சிக்கும் கோப்புகளானது இந்த சேவையகத்தில் கோப்பு பதிவேற்றக்கூடிய ஆகக்கூடிய அளவிலும் கூடியது.",
    "Files are being scanned, please wait." : "கோப்புகள் வருடப்படுகின்றன, தயவுசெய்து காத்திருங்கள்."
},
"nplurals=2; plural=(n != 1);");

==> php55-owncloud-9.0.0.tgz: share/owncloud/apps/files/l10n/ta_LK.js <==
OC.L10N.register(
    "files",
    {
    "No file was uploaded. Unknown error" : "ஒரு கோப்பும் பதிவேற்றப்படவில்லை. அறியப்படாத வழு",
    "There is no error, the file uploaded with success" : "இங்கு வழு இல்லை, கோப்பு வெற்றிகரமாக பதிவேற்றப்பட்டது",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "பதிவேற்றப்பட்ட கோப்பானது HTML  படிவத்தில் குறிப்பிடப்பட்டுள்ள MAX_FILE_SIZE  directive ஐ விட கூடியது",
    "The uploaded file was only partially uploaded" : "பதிவேற்றப்பட்ட கோப்பானது பகுதியாக மட்டுமே பதிவேற்றப்பட்டுள்ளது",
    "No file was uploaded" : "எந்த கோப்பும் பதிவேற்றப்படவில்லை",
    "Missing a temporary folder" : "ஒரு தற்காலிகமான கோப்புறையை காணவில்லை",
    "Failed to write to disk" : "வட்டில் எழுத முடியவில்லை",
    "Files" : "கோப்புகள்",
    "Favorites" : "விருப்பங்கள்",
    "Home" : "அகம்",
    "Close" : "மூடுக",
    "Upload cancelled." : "பதிவேற்றல் இரத்து செய்யப்பட்டுள்ளது",
    "File upload is in progress. Leaving the page now will cancel the upload." : "கோப்பு பதிவேற்றம் செயல்பாட்டில் உள்ளது. இந்தப் பக்கத்திலிருந்து வெறியேறுவதானது பதிவேற்றலை இரத்து செய்யும்.",
    "Actions" : "செயல்கள்",
    "Download" : "பதிவிறக்குக",
    "Rename" : "பெயர்மாற்றம்",
    "Delete" : "நீக்குக",
    "Unshare" : "பகிரப்படாதது",
    "Details" : "விவரங்கள்",
    "Select" : "தெரிக",
    "Pending" : "நிலுவையிலுள்ள",
    "Name" : "பெயர்",
    "Size" : "அளவு",
    "Modified" : "மாற்றப்பட்டது",
    "New" : "புதிய",
    "Favorite" : "விருப்பமான",
    "Folder" : "கோப்புறை",
    "Upload" : "பதிவேற்றுக",
    "File handling" : "கோப்பு கையாளுதல்",
    "Maximum upload size" : "பதிவேற்றக்கூடிய ஆகக்கூடிய அளவு ",
    "max. possible: " : "ஆகக் கூடியது:",
    "Save" : "சேமிக்க ",
    "Settings" : "அமைப்புகள்",
    "Cancel upload" : "பதிவேற்றலை இரத்து செய்க",
    "Upload too large" : "பதிவேற்றல் மிகப்பெரியது",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "நீங்கள் பதிவேற்ற முயற்சிக்கும் கோப்புகளானது இந்த சேவையகத்தில் கோப்பு பதிவேற்றக்கூடிய ஆகக்கூடிய அளவிலும் கூடியது.",
    "Text file" : "கோப்பு உரை"
},
"nplurals=2; plural=(n != 1);");
